==> jc-1.4.0.tar.gz: javax/imageio/metadata/IIOInvalidTreeException.h <==
// public class javax.imageio.metadata.IIOInvalidTreeException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 360a325ae7243532 javax_imageio_IIOException
// @dep_class 8f1849ba4c63000c javax_imageio_metadata_IIOInvalidTreeException

// header file dependencies
// @dep_header javax_imageio_IIOException

#include "javax/imageio/IIOException.h"

#ifndef _JC_javax_imageio_metadata_IIOInvalidTreeException_H_
#define _JC_javax_imageio_metadata_IIOInvalidTreeException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_javax_imageio_metadata_IIOInvalidTreeException$sub_refs	_jc_javax_imageio_metadata_IIOInvalidTreeException$sub_refs;
typedef struct _jc_javax_imageio_metadata_IIOInvalidTreeException$sub_nonrefs	_jc_javax_imageio_metadata_IIOInvalidTreeException$sub_nonrefs;
typedef struct _jc_javax_imageio_metadata_IIOInvalidTreeException$refs	_jc_javax_imageio_metadata_IIOInvalidTreeException$refs;
typedef struct _jc_javax_imageio_metadata_IIOInvalidTreeException$nonrefs	_jc_javax_imageio_metadata_IIOInvalidTreeException$nonrefs;
typedef struct _jc_javax_imageio_metadata_IIOInvalidTreeException$object	_jc_javax_imageio_metadata_IIOInvalidTreeException$object;

typedef struct _jc_javax_imageio_metadata_IIOInvalidTreeException$fields_struct	_jc_javax_imageio_metadata_IIOInvalidTreeException$fields_struct;
typedef const struct _jc_javax_imageio_metadata_IIOInvalidTreeException$vmethods	_jc_javax_imageio_metadata_IIOInvalidTreeException$vmethods;
typedef const struct _jc_javax_imageio_metadata_IIOInvalidTreeException$vtable	_jc_javax_imageio_metadata_IIOInvalidTreeException$vtable;
typedef const struct _jc_javax_imageio_metadata_IIOInvalidTreeException$vtype	_jc_javax_imageio_metadata_IIOInvalidTreeException$vtype;

// Class fields structure
struct _jc_javax_imageio_metadata_IIOInvalidTreeException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_imageio_metadata_IIOInvalidTreeException$fields_struct _jc_javax_imageio_metadata_IIOInvalidTreeException$class_fields;

// Constructors
extern void _jc_javax_imageio_metadata_IIOInvalidTreeException$method$_init$fbbd503e56b69dca(_jc_env *, struct _jc_javax_imageio_metadata_IIOInvalidTreeException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *, struct _jc_object *);
extern void _jc_javax_imageio_metadata_IIOInvalidTreeException$method$_init$fce1b8c444e4f2d2(_jc_env *, struct _jc_javax_imageio_metadata_IIOInvalidTreeException$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_javax_imageio_metadata_IIOInvalidTreeException$method$getOffendingNode$a6c470c2a870b620(_jc_env *, struct _jc_javax_imageio_metadata_IIOInvalidTreeException$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_metadata_IIOInvalidTreeException$method_info$getOffendingNode$a6c470c2a870b620;

// Virtual methods structure
struct _jc_javax_imageio_metadata_IIOInvalidTreeException$vmethods {
	struct _jc_object	*(*getOffendingNode$a6c470c2a870b620)(_jc_env *, struct _jc_javax_imageio_metadata_IIOInvalidTreeException$object *);
};

// Vtable
struct _jc_javax_imageio_metadata_IIOInvalidTreeException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_javax_imageio_IIOException$vmethods	javax_imageio_IIOException;
	_jc_javax_imageio_metadata_IIOInvalidTreeException$vmethods	javax_imageio_metadata_IIOInvalidTreeException;
};

// Vtype
struct _jc_javax_imageio_metadata_IIOInvalidTreeException$vtype {
	_jc_type			type;
	_jc_javax_imageio_metadata_IIOInvalidTreeException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_metadata_IIOInvalidTreeException$sub_refs {
	struct _jc_object	*offendingNode;
};

// Reference instance fields (object)
struct _jc_javax_imageio_metadata_IIOInvalidTreeException$refs {
    _jc_javax_imageio_metadata_IIOInvalidTreeException$sub_refs	javax_imageio_metadata_IIOInvalidTreeException;
    _jc_javax_imageio_IIOException$sub_refs	javax_imageio_IIOException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_metadata_IIOInvalidTreeException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_metadata_IIOInvalidTreeException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_javax_imageio_IIOException$sub_nonrefs	javax_imageio_IIOException;
    _jc_javax_imageio_metadata_IIOInvalidTreeException$sub_nonrefs	javax_imageio_metadata_IIOInvalidTreeException;
};

// Object instance structure
struct _jc_javax_imageio_metadata_IIOInvalidTreeException$object {
	_jc_javax_imageio_metadata_IIOInvalidTreeException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_metadata_IIOInvalidTreeException$vtype	*vtype;
	_jc_javax_imageio_metadata_IIOInvalidTreeException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_metadata_IIOInvalidTreeException$vtype _jc_javax_imageio_metadata_IIOInvalidTreeException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_metadata_IIOInvalidTreeException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_metadata_IIOInvalidTreeException$class_object;

#endif	/* _JC_javax_imageio_metadata_IIOInvalidTreeException_H_ */

==> jc-1.4.6.tar.gz: javax/imageio/metadata/IIOInvalidTreeException.h <==
// public class javax.imageio.metadata.IIOInvalidTreeException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 360a325ae7243532 javax_imageio_IIOException
// @dep_class 8f1849ba4c63000c javax_imageio_metadata_IIOInvalidTreeException

// header file dependencies
// @dep_header javax_imageio_IIOException

#include "javax/imageio/IIOException.h"

#ifndef _JC_javax_imageio_metadata_IIOInvalidTreeException_H_
#define _JC_javax_imageio_metadata_IIOInvalidTreeException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_javax_imageio_metadata_IIOInvalidTreeException$sub_refs	_jc_javax_imageio_metadata_IIOInvalidTreeException$sub_refs;
typedef struct _jc_javax_imageio_metadata_IIOInvalidTreeException$sub_nonrefs	_jc_javax_imageio_metadata_IIOInvalidTreeException$sub_nonrefs;
typedef struct _jc_javax_imageio_metadata_IIOInvalidTreeException$refs	_jc_javax_imageio_metadata_IIOInvalidTreeException$refs;
typedef struct _jc_javax_imageio_metadata_IIOInvalidTreeException$nonrefs	_jc_javax_imageio_metadata_IIOInvalidTreeException$nonrefs;
typedef struct _jc_javax_imageio_metadata_IIOInvalidTreeException$object	_jc_javax_imageio_metadata_IIOInvalidTreeException$object;

typedef struct _jc_javax_imageio_metadata_IIOInvalidTreeException$fields_struct	_jc_javax_imageio_metadata_IIOInvalidTreeException$fields_struct;
typedef const struct _jc_javax_imageio_metadata_IIOInvalidTreeException$vmethods	_jc_javax_imageio_metadata_IIOInvalidTreeException$vmethods;
typedef const struct _jc_javax_imageio_metadata_IIOInvalidTreeException$vtable	_jc_javax_imageio_metadata_IIOInvalidTreeException$vtable;
typedef const struct _jc_javax_imageio_metadata_IIOInvalidTreeException$vtype	_jc_javax_imageio_metadata_IIOInvalidTreeException$vtype;

// Class fields structure
struct _jc_javax_imageio_metadata_IIOInvalidTreeException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_imageio_metadata_IIOInvalidTreeException$fields_struct _jc_javax_imageio_metadata_IIOInvalidTreeException$class_fields;

// Constructors
extern void _jc_javax_imageio_metadata_IIOInvalidTreeException$method$_init$fbbd503e56b69dca(_jc_env *, struct _jc_javax_imageio_metadata_IIOInvalidTreeException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_metadata_IIOInvalidTreeException$method$_init$fce1b8c444e4f2d2(_jc_env *, struct _jc_javax_imageio_metadata_IIOInvalidTreeException$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_imageio_metadata_IIOInvalidTreeException$method$getOffendingNode$a6c470c2a870b620(_jc_env *, struct _jc_javax_imageio_metadata_IIOInvalidTreeException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_metadata_IIOInvalidTreeException$method_info$getOffendingNode$a6c470c2a870b620;

// Virtual methods structure
struct _jc_javax_imageio_metadata_IIOInvalidTreeException$vmethods {
	struct _jc_object	*(*getOffendingNode$a6c470c2a870b620)(_jc_env *, struct _jc_javax_imageio_metadata_IIOInvalidTreeException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_imageio_metadata_IIOInvalidTreeException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_javax_imageio_IIOException$vmethods	javax_imageio_IIOException;
	_jc_javax_imageio_metadata_IIOInvalidTreeException$vmethods	javax_imageio_metadata_IIOInvalidTreeException;
};

// Vtype
struct _jc_javax_imageio_metadata_IIOInvalidTreeException$vtype {
	_jc_type			type;
	_jc_javax_imageio_metadata_IIOInvalidTreeException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_metadata_IIOInvalidTreeException$sub_refs {
	struct _jc_object	*offendingNode;
};

// Reference instance fields (object)
struct _jc_javax_imageio_metadata_IIOInvalidTreeException$refs {
    _jc_javax_imageio_metadata_IIOInvalidTreeException$sub_refs	javax_imageio_metadata_IIOInvalidTreeException;
    _jc_javax_imageio_IIOException$sub_refs	javax_imageio_IIOException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_metadata_IIOInvalidTreeException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_metadata_IIOInvalidTreeException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_javax_imageio_IIOException$sub_nonrefs	javax_imageio_IIOException;
    _jc_javax_imageio_metadata_IIOInvalidTreeException$sub_nonrefs	javax_imageio_metadata_IIOInvalidTreeException;
};

// Object instance structure
struct _jc_javax_imageio_metadata_IIOInvalidTreeException$object {
	_jc_javax_imageio_metadata_IIOInvalidTreeException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_metadata_IIOInvalidTreeException$vtype	*vtype;
	_jc_javax_imageio_metadata_IIOInvalidTreeException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_metadata_IIOInvalidTreeException$vtype _jc_javax_imageio_metadata_IIOInvalidTreeException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_metadata_IIOInvalidTreeException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_metadata_IIOInvalidTreeException$class_object;

#endif	/* _JC_javax_imageio_metadata_IIOInvalidTreeException_H_ */
